@@ -200,7 +200,7 @@ def piggo_upload(web,file1,record_path,qbinfo):
             select_source_sel_ob.select_by_value('5')
         elif 'AC3' in file1.Audio_Format.upper() or 'DD' in file1.Audio_Format.upper():
             select_source_sel_ob.select_by_value('8')
-        elif 'DTS:X' in file1.Audio_Format.upper():
+        elif 'DTS:X' in file1.Audio_Format.upper() or 'DTS-X' in file1.Audio_Format.upper():
             select_source_sel_ob.select_by_value('3')
         elif 'DTS' in file1.Audio_Format.upper():
             select_source_sel_ob.select_by_value('3')
